@@ -1,7 +1,8 @@
 # frozen_string_literal: true
 
-RSpec.describe ::JWT::Verify do
+RSpec.describe JWT::Verify do
   let(:base_payload) { { 'user_id' => 'some@user.tld' } }
+  let(:string_payload) { 'beautyexperts_nbf_iat' }
   let(:options) { { leeway: 0 } }
 
   context '.verify_aud(payload, options)' do
@@ -64,6 +65,10 @@ RSpec.describe ::JWT::Verify do
       end.to raise_error JWT::ExpiredSignature
     end
 
+    it 'must not consider string containing exp as expired' do
+      expect(described_class.verify_expiration(string_payload, options)).to eq(nil)
+    end
+
     context 'when leeway is not specified' do
       let(:options) { {} }
 
@@ -84,7 +89,7 @@ RSpec.describe ::JWT::Verify do
     end
 
     it 'must ignore configured leeway' do
-      expect{described_class.verify_iat(payload.merge('iat' => (iat + 60)), options.merge(leeway: 70)) }
+      expect { described_class.verify_iat(payload.merge('iat' => (iat + 60)), options.merge(leeway: 70)) }
         .to raise_error(JWT::InvalidIatError)
     end
 
@@ -103,6 +108,10 @@ RSpec.describe ::JWT::Verify do
         described_class.verify_iat(payload.merge('iat' => (iat + 120)), options)
       end.to raise_error JWT::InvalidIatError
     end
+
+    it 'must not validate if the payload is a string containing iat' do
+      expect(described_class.verify_iat(string_payload, options)).to eq(nil)
+    end
   end
 
   context '.verify_iss(payload, options)' do
@@ -145,6 +154,65 @@ RSpec.describe ::JWT::Verify do
         described_class.verify_iss(payload, options.merge(iss: ['first', iss, 'third']))
       end
     end
+    context 'when iss is a RegExp' do
+      it 'must raise JWT::InvalidIssuerError when the regular expression does not match' do
+        expect do
+          described_class.verify_iss(payload, options.merge(iss: /\A(first|second)\z/))
+        end.to raise_error JWT::InvalidIssuerError
+      end
+
+      it 'must raise JWT::InvalidIssuerError when the payload does not include an issuer' do
+        expect do
+          described_class.verify_iss(base_payload, options.merge(iss: /\A(first|second)\z/))
+        end.to raise_error(JWT::InvalidIssuerError, /received <none>/)
+      end
+
+      it 'must allow a regular expression matching the issuer to pass' do
+        described_class.verify_iss(payload, options.merge(iss: /\A(first|#{iss}|third)\z/))
+      end
+    end
+    context 'when iss is a Proc' do
+      it 'must raise JWT::InvalidIssuerError when the proc returns false' do
+        expect do
+          described_class.verify_iss(payload, options.merge(iss: ->(iss) { iss && iss.start_with?('first') }))
+        end.to raise_error JWT::InvalidIssuerError
+      end
+
+      it 'must raise JWT::InvalidIssuerError when the payload does not include an issuer' do
+        expect do
+          described_class.verify_iss(base_payload, options.merge(iss: ->(iss) { iss && iss.start_with?('first') }))
+        end.to raise_error(JWT::InvalidIssuerError, /received <none>/)
+      end
+
+      it 'must allow a proc that returns true to pass' do
+        described_class.verify_iss(payload, options.merge(iss: ->(iss) { iss && iss.start_with?('ruby') }))
+      end
+    end
+    context 'when iss is a Method instance' do
+      def issuer_start_with_first?(issuer)
+        issuer&.start_with?('first')
+      end
+
+      def issuer_start_with_ruby?(issuer)
+        issuer&.start_with?('ruby')
+      end
+
+      it 'must raise JWT::InvalidIssuerError when the method returns false' do
+        expect do
+          described_class.verify_iss(payload, options.merge(iss: method(:issuer_start_with_first?)))
+        end.to raise_error JWT::InvalidIssuerError
+      end
+
+      it 'must raise JWT::InvalidIssuerError when the payload does not include an issuer' do
+        expect do
+          described_class.verify_iss(base_payload, options.merge(iss: method(:issuer_start_with_first?)))
+        end.to raise_error(JWT::InvalidIssuerError, /received <none>/)
+      end
+
+      it 'must allow a method that returns true to pass' do
+        described_class.verify_iss(payload, options.merge(iss: method(:issuer_start_with_ruby?)))
+      end
+    end
   end
 
   context '.verify_jti(payload, options)' do
@@ -178,7 +246,7 @@ RSpec.describe ::JWT::Verify do
 
     it 'it should not throw arguement error with 2 args' do
       expect do
-        described_class.verify_jti(payload, options.merge(verify_jti: ->(_jti, pl) {
+        described_class.verify_jti(payload, options.merge(verify_jti: ->(_jti, _pl) {
           true
         }))
       end.to_not raise_error
@@ -206,6 +274,10 @@ RSpec.describe ::JWT::Verify do
     it 'must allow some leeway in the token age when nbf_leeway is configured' do
       described_class.verify_not_before(payload, options.merge(nbf_leeway: 10))
     end
+
+    it 'must not validate if the payload is a string containing iat' do
+      expect(described_class.verify_not_before(string_payload, options)).to eq(nil)
+    end
   end
 
   context '.verify_sub(payload, options)' do
